.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth Technical Notes.

TotalDepth Technical Notes
=============================

This collect together various technical descriptions of how TotalDepth solves certain problems.

Contents:

.. toctree::
    :maxdepth: 3
   
    LIS_indexing
    
    performance
    
    plotting
    
    saas
